from setuptools import setup, find_packages
import sys, os

version = '0.0.1'

setup(name='sane_logger',
      version=version,
      description="My preferred logger config.",
      long_description="""""",
      classifiers=[],
      keywords='logging',
      author='Jesse Aldridge',
      author_email='JesseAldridge@gmail.com',
      url='https://github.com/JesseAldridge/sane_logger',
      license='MIT',
      packages=['sane_logger'],
      include_package_data=True,
      zip_safe=True,
      install_requires=[
          # -*- Extra requirements: -*-
      ]
      )



import logging, sys


def setup_logger():
  logger = logging.getLogger()
  logger.setLevel(logging.DEBUG)

  sh = logging.StreamHandler(sys.stdout)
  formatter = logging.Formatter(
    '[%(asctime)s] %(levelname)s [%(filename)s.%(funcName)s:%(lineno)d] %(message)s',
    datefmt='%a, %d %b %Y %H:%M:%S'
  )
  sh.setFormatter(formatter)
  logger.addHandler(sh)
  return logger

if __name__ == '__main__':
  logger = setup_logger()
  logger.info('test log')
